@@ -50,7 +50,7 @@ class FileObject(object):
     # This is necessary so the Runner can cleanup temp files that have been created
     # for backwards compatibility.
     # TODO: Remove this when original implementation of .file_path is removed.
-    _instances = []
+    _instances: List[FileObject] = []
 
     def __init__(
         self,
@@ -180,7 +180,7 @@ class FileObject(object):
         with io.BytesIO(self.data) as fo:
             yield fo
 
-    def _cleanup(self):
+    def _clear_temp_path_ctx(self):
         """
         Cleans up temporary file if created.
         TODO: This is temporary in order to support backwards compatibility.
@@ -190,7 +190,16 @@ class FileObject(object):
             self._temp_path_ctx = None
             self._temp_path = None
 
-    def add_tag(self, *tags: Iterable[str]) -> "FileObject":
+    @classmethod
+    def _cleanup(cls):
+        """
+        Cleans up instances of FileObject.
+        """
+        for file_object in cls._instances:
+            file_object._clear_temp_path_ctx()
+        cls._instances = []
+
+    def add_tag(self, *tags: Iterable[str]) -> FileObject:
         """
         Adds tag(s) for the file.
 
@@ -210,12 +219,27 @@ class FileObject(object):
         return self._report
 
     @property
-    def siblings(self) -> List["FileObject"]:
+    def siblings(self) -> List[FileObject]:
         """List of FileObjects that came from the same parent."""
         if not self.parent:
             return []
         return [fo for fo in self.parent.children if fo is not self]
 
+    @property
+    def ancestors(self) -> List[FileObject]:
+        """List of FileObjects for the full parental hierarchy."""
+        if not self.parent:
+            return []
+        return [self.parent, *self.parent.ancestors]
+
+    @property
+    def descendants(self) -> List[FileObject]:
+        """List of FileObjects that came from the current file."""
+        ret = list(self.children)
+        for child in self.children:
+            ret.extend(child.descendants)
+        return ret
+
     @property
     def file_data(self):
         warnings.warn(
@@ -273,6 +297,18 @@ class FileObject(object):
             logger.info("Renamed {} to {}".format(self._name, value))
         self._name = value
 
+    @property
+    def ext(self):
+        """The extension of the file."""
+        return pathlib.PurePath(self.name).suffix
+
+    @ext.setter
+    def ext(self, new_ext: str):
+        """Sets a new extension for the file."""
+        if not new_ext.startswith("."):
+            new_ext = f".{new_ext}"
+        self.name = pathlib.PurePath(self.name).stem + new_ext
+
     @property
     def parser_history(self):
         """
@@ -372,7 +408,7 @@ class FileObject(object):
             return self._file_path
 
         if not self._temp_path:
-            self._cleanup()
+            self._clear_temp_path_ctx()
             self._temp_path_ctx = self.temp_path()
             self._temp_path = self._temp_path_ctx.__enter__()
         return self._temp_path
@@ -468,13 +504,15 @@ class FileObject(object):
 
         with self.temp_path() as file_path:
             with dragodis.open_program(file_path, disassembler, **config) as dis:
+                bit_size = dis.bit_size
                 yield dis
 
             # After processing we want to save the annotated project file if report was provided.
             if report:
                 project_file = None
                 if dis.name.casefold() == "ida":
-                    project_file = dis.input_path.parent / (dis.input_path.name + ".idb")
+                    ext = ".i64" if bit_size == 64 else ".idb"
+                    project_file = dis.input_path.parent / (dis.input_path.name + ext)
                 elif dis.name.casefold() == "ghidra":
                     folder_path = dis.input_path.parent / (dis.input_path.name + "_ghidra")
                     project_file = pathlib.Path(shutil.make_archive(
